"""Scoring checks."""
from abc import ABC, abstractmethod
from typing import Any, Dict, Tuple

from regal import Contact

from ..models import CheckResult


class BaseCheck(ABC):
    """Base class for scoring check.

    Attributes:
        name: The name of the check.
    """

    def __init__(self, *, name: str):
        self.name = name

    def __repr__(self) -> str:
        return '<{} {!r}>'.format(type(self).__name__, self.name)

    @abstractmethod
    async def _get_results(self, contact: Contact) -> Tuple[Dict[str, Any], float]:
        """Collect and return check details and value."""

    async def evaluate(self, contact: Contact) -> CheckResult:
        """Evaluate the contact.

        Raises:
            SkipEvaluation: If the evaluation of the contact should be skipped.
        """
        details, value = await self._get_results(contact)
        return CheckResult(name=self.name, details=details, value=value)
