#!/usr/bin/python3
"""Evaluate contacts in queue."""
import asyncio
import logging
from datetime import timedelta
from time import sleep

import click
from setapp.constants import Verbosity

from verification.commands.utils import echo, verification_command
from verification.evaluator import Evaluator

_LOGGER = logging.getLogger(__name__)
_OUT_MSG = ('Evaluate: {total} total, {result.successes} evaluated, {result.skips} skipped, '
            '{result.errors} errors.')


@verification_command()
@click.option('--loop', default=False, is_flag=True, help="Run in infinite loop.")
@click.option('--loop-delay', default=3600, show_default=True,
              help="Set delay in seconds between batches in loop mode.")
@click.option('--renew-delay', default=30*86400, show_default=True,
              help="A minimal number of seconds between two evaluations of the same contact.")
@click.option('--skip-delay', default=86400, show_default=True,
              help="A minimal number of seconds to exclude skipped contact from evaluation.")
@click.option('--throttle', default=10, show_default=True,
              help="A number of seconds between any two evaluations.")
def main(renew_delay: int, throttle: int, loop: bool, loop_delay: int, skip_delay: int) -> None:
    """Evaluate contacts in queue."""
    evaluator = Evaluator()
    while not evaluator.stop_process:
        result = asyncio.run(evaluator.evaluate_all(renew_delay=timedelta(seconds=renew_delay), throttle=throttle,
                                                    skip_delay=timedelta(seconds=skip_delay)))
        echo(_OUT_MSG.format(total=result.total(), result=result), Verbosity.INFO, log=_LOGGER.info)
        if not loop:
            break
        sleep(loop_delay)


if __name__ == '__main__':
    main()
