#!/usr/bin/python3
"""Process open or recently closed verifications."""
import asyncio
import logging
from time import sleep

import click
from setapp.constants import Verbosity

from verification.commands.utils import echo, verification_command
from verification.settings import APPLICATION

_LOGGER = logging.getLogger(__name__)
_OUT_MSG = ('Verifications: {total} total, {result.successes} processed, {result.skips} skipped, '
            '{result.errors} errors.')


@verification_command()
@click.option('--loop', default=False, is_flag=True, help="Run in infinite loop.")
@click.option('--loop-delay', default=300, show_default=True, help="Set delay in seconds between batches in loop mode.")
@click.option('--closed-limit', default=86400, show_default=True,
              help="A number of seconds passed since a verification is closed in order to be processed.")
def main(closed_limit: int, loop: bool, loop_delay: int) -> None:
    """Process open or recently closed verifications."""
    while not APPLICATION.handler.stop_process:
        result = asyncio.run(APPLICATION.handler.process_all(closed_limit=closed_limit))
        echo(_OUT_MSG.format(total=result.total(), result=result), Verbosity.INFO, log=_LOGGER.info)
        if not loop:
            break
        sleep(loop_delay)


if __name__ == '__main__':
    main()
