import asyncio

from alembic import context
from sqlalchemy.engine import Connection

from verification.database import get_engine
from verification.models import METADATA
from verification.settings import APPLICATION

# This script is run by alembic command. We need to load settings here.
APPLICATION.load()


def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an Engine, though an Engine is acceptable
    here as well.  By skipping the Engine creation
    we don't even need a DBAPI to be available.

    Calls to context.execute() here emit the given string to the
    script output.

    """
    url = context.config.get_main_option("sqlalchemy.url")
    context.configure(
        url=url,
        target_metadata=METADATA,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()


def run_migrations(connection: Connection):
    """Actually run migrations."""
    context.configure(
        connection=connection,
        target_metadata=METADATA,
        # Use batch mode for SQLite ALTERs.
        # See https://alembic.sqlalchemy.org/en/latest/batch.html#batch-mode-with-autogenerate
        render_as_batch=True,
        # Required for enum updates in postgresql.
        transaction_per_migration=True,
    )

    context.run_migrations()


async def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create an Engine
    and associate a connection with the context.
    """
    # Use our internal utility to get the engine.
    engine = get_engine()

    async with engine.connect() as connection:
        await connection.run_sync(run_migrations)

    await engine.dispose()


if context.is_offline_mode():
    run_migrations_offline()
else:
    asyncio.run(run_migrations_online())
