"""Add score

Revision ID: 161cc0f7f78d
Revises: 08ffe052b62c
Create Date: 2023-09-19 12:39:27.373563+00:00

"""
import sqlalchemy as sa
from alembic import op
from sqlalchemy.sql import func
from sqlalchemy_utc import UtcDateTime
from sqlalchemy_utils import JSONType

# revision identifiers, used by Alembic.
revision = "161cc0f7f78d"
down_revision = "08ffe052b62c"
branch_labels = None
depends_on = None


def upgrade() -> None:
    op.create_table(
        "verification_score",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("contact_id", sa.Text(), nullable=False),
        sa.Column("contact_history_id", sa.Text(), nullable=False),
        sa.Column(
            "create_datetime",
            UtcDateTime(timezone=True),
            server_default=func.now(),
            nullable=False,
        ),
        sa.Column("value", sa.Float(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("verification_score_pkey")),
    )
    op.create_table(
        "verification_scorequeue",
        sa.Column("id", sa.Text(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("verification_scorequeue_pkey")),
    )
    op.create_table(
        "verification_checkresult",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("score_id", sa.Integer(), nullable=False),
        sa.Column("name", sa.Text(), nullable=False),
        sa.Column("value", sa.Float(), nullable=False),
        sa.Column("details", JSONType(), nullable=False),
        sa.ForeignKeyConstraint(
            ["score_id"], ["verification_score.id"], name=op.f("verification_checkresult_score_id_fk")
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("verification_checkresult_pkey")),
        sa.UniqueConstraint("score_id", "name", name="verification_checkresult_name_key"),
    )
    with op.batch_alter_table("verification_checkresult", schema=None) as batch_op:
        batch_op.create_index(batch_op.f("verification_checkresult_score_id_key"), ["score_id"], unique=False)


def downgrade() -> None:
    with op.batch_alter_table("verification_checkresult", schema=None) as batch_op:
        batch_op.drop_index(batch_op.f("verification_checkresult_score_id_key"))

    op.drop_table("verification_checkresult")
    op.drop_table("verification_scorequeue")
    op.drop_table("verification_score")
