"""Add new statuses.

Revision ID: 37304aea0b20
Revises: 1f326f8c981c
Create Date: 2023-06-26 11:04:23.170377+00:00

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "37304aea0b20"
down_revision = "1f326f8c981c"
branch_labels = None
depends_on = None


def upgrade() -> None:
    connection = op.get_bind()
    if connection.dialect.name == "postgresql":
        connection.execute(sa.text("ALTER TYPE verificationstatus ADD VALUE 'PAUSED' AFTER 'FUTILE'"))
        connection.execute(sa.text("ALTER TYPE verificationstatus ADD VALUE 'MANUAL' AFTER 'CANCELED'"))
    else:
        old_status = sa.Enum(
            "CREATED",
            "INITIALIZED",
            "ACCESSED",
            "PENDING",
            "CONSTRAINED",
            "FUTILE",
            "SUCCEEDED",
            "FAILED",
            "CANCELED",
            name="verificationstatus",
        )
        status = sa.Enum(
            "CREATED",
            "INITIALIZED",
            "ACCESSED",
            "PENDING",
            "CONSTRAINED",
            "FUTILE",
            "PAUSED",
            "SUCCEEDED",
            "FAILED",
            "CANCELED",
            "MANUAL",
            name="verificationstatus",
            create_constraint=True,
        )
        with op.batch_alter_table("verification_verification", schema=None) as batch_op:
            batch_op.alter_column("status", type_=status, existing_type=old_status)


def downgrade() -> None:
    connection = op.get_bind()
    if connection.dialect.name != "postgresql":
        old_status = sa.Enum(
            "CREATED",
            "INITIALIZED",
            "ACCESSED",
            "PENDING",
            "CONSTRAINED",
            "FUTILE",
            "PAUSED",
            "SUCCEEDED",
            "FAILED",
            "CANCELED",
            "MANUAL",
            name="verificationstatus",
            create_constraint=True,
        )
        status = sa.Enum(
            "CREATED",
            "INITIALIZED",
            "ACCESSED",
            "PENDING",
            "CONSTRAINED",
            "FUTILE",
            "SUCCEEDED",
            "FAILED",
            "CANCELED",
            name="verificationstatus",
        )
        with op.batch_alter_table("verification_verification", schema=None) as batch_op:
            batch_op.alter_column("status", type_=status, existing_type=old_status)
