"""Models for contact scoring."""
from datetime import datetime
from typing import Any, Dict, List, Optional

from fred_types import ContactHistoryId, ContactId
from sqlalchemy import ForeignKey, UniqueConstraint
from sqlalchemy.orm import Mapped, mapped_column, relationship
from sqlalchemy.sql import func
from sqlalchemy_utils import JSONType

from .base import BaseModel


class ScoreQueue(BaseModel):
    """Represents a queue of contact IDs to be scored."""

    id: Mapped[ContactId] = mapped_column(primary_key=True)  # type: ignore[assignment]
    skipped_at: Mapped[Optional[datetime]]


class Score(BaseModel):
    """Represents a contact score."""

    contact_id: Mapped[ContactId] = mapped_column(index=True)
    contact_history_id: Mapped[ContactHistoryId]
    create_datetime: Mapped[datetime] = mapped_column(server_default=func.now())
    value: Mapped[float]

    check_results: Mapped[List["CheckResult"]] = relationship('CheckResult')


class CheckResult(BaseModel):
    """Represents result of a single check of a contact."""

    score_id: Mapped[int] = mapped_column(ForeignKey(Score.id), index=True)
    name: Mapped[str]
    value: Mapped[float]
    details: Mapped[Dict[str, Any]] = mapped_column(JSONType(), default=dict)

    __table_args__ = (
        UniqueConstraint('score_id', 'name', name='verification_checkresult_name_key'),
    )
