"""Processor for mojeid method."""
from sqlalchemy import null, or_, select

from ..database import object_session
from ..models import ContactData, Verification
from .base import BaseProcessor


class MojeidProcessor(BaseProcessor):
    """Processor for mojeid method."""

    async def check_complete(self, verification: Verification) -> bool:
        """Return whether all verification steps were already completed."""
        session = object_session(verification)

        query = select(ContactData).filter(
            ContactData.verification_id == verification.id,
            or_(ContactData.method == null(), ContactData.method == self.method))
        query = query.order_by(ContactData.verify_datetime.desc())
        records = (await session.execute(query)).scalars().all()

        # Check whether the result is a company based on the most recent record.
        is_company = None
        for record in records:
            if record.verified_organization:
                is_company = record.organization != ''
                break
        else:
            # It's not even sure whether it's a company or a person.
            return False

        if is_company and not any(r.verified_company_registration_number for r in records):
            # It's a company, but its company registration number was never verified.
            return False

        return await super().check_complete(verification)
