from unittest import TestCase
from unittest.mock import sentinel

from verification.constants import VerificationStatus


class VerificationStatusTest(TestCase):
    data = (
        # A < B
        (VerificationStatus.CREATED, VerificationStatus.INITIALIZED),
        (VerificationStatus.INITIALIZED, VerificationStatus.ACCESSED),
        (VerificationStatus.ACCESSED, VerificationStatus.PENDING),
        (VerificationStatus.PENDING, VerificationStatus.CONSTRAINED),
        (VerificationStatus.CONSTRAINED, VerificationStatus.FUTILE),
        (VerificationStatus.FUTILE, VerificationStatus.PAUSED),
        (VerificationStatus.PAUSED, VerificationStatus.SUCCEEDED),
        (VerificationStatus.PAUSED, VerificationStatus.FAILED),
        (VerificationStatus.PAUSED, VerificationStatus.CANCELED),
        (VerificationStatus.PAUSED, VerificationStatus.MANUAL),
    )
    incomparable_data = (
        # A ?? B
        (VerificationStatus.SUCCEEDED, VerificationStatus.FAILED),
        (VerificationStatus.SUCCEEDED, VerificationStatus.CANCELED),
        (VerificationStatus.SUCCEEDED, VerificationStatus.MANUAL),
        (VerificationStatus.FAILED, VerificationStatus.CANCELED),
        (VerificationStatus.FAILED, VerificationStatus.MANUAL),
        (VerificationStatus.CANCELED, VerificationStatus.MANUAL),
    )

    def test_comparison_itself(self):
        for status in VerificationStatus:
            with self.subTest(status=status):
                self.assertTrue(status == status)
                self.assertFalse(status != status)

                self.assertFalse(status > status)
                self.assertTrue(status >= status)
                self.assertTrue(status <= status)
                self.assertFalse(status < status)

    def test_comparison(self):
        for first, second in self.data:
            with self.subTest(first=first, second=second):
                self.assertFalse(first == second)
                self.assertFalse(second == first)
                self.assertTrue(first != second)
                self.assertTrue(second != first)

                self.assertTrue(first < second)
                self.assertTrue(first <= second)
                self.assertFalse(first >= second)
                self.assertFalse(first > second)

                self.assertFalse(second < first)
                self.assertFalse(second <= first)
                self.assertTrue(second >= first)
                self.assertTrue(second > first)

    def test_comparison_incomparable(self):
        for first, second in self.incomparable_data:
            with self.subTest(first=first, second=second):
                self.assertFalse(first == second)
                self.assertFalse(second == first)
                self.assertTrue(first != second)
                self.assertTrue(second != first)

                self.assertFalse(first < second)
                self.assertFalse(first <= second)
                self.assertFalse(first >= second)
                self.assertFalse(first > second)

                self.assertFalse(second < first)
                self.assertFalse(second <= first)
                self.assertFalse(second >= first)
                self.assertFalse(second > first)

    def test_comparison_other(self):
        self.assertFalse(VerificationStatus.CREATED == sentinel.other)
        self.assertTrue(VerificationStatus.CREATED != sentinel.other)

        with self.assertRaisesRegex(TypeError, 'not supported between instances'):
            VerificationStatus.CREATED < sentinel.other
        with self.assertRaisesRegex(TypeError, 'not supported between instances'):
            VerificationStatus.CREATED <= sentinel.other
        with self.assertRaisesRegex(TypeError, 'not supported between instances'):
            VerificationStatus.CREATED >= sentinel.other
        with self.assertRaisesRegex(TypeError, 'not supported between instances'):
            VerificationStatus.CREATED > sentinel.other
