from fred_types import ContactHistoryId, ContactId

from verification.processors import MojeidProcessor

from .utils import TransactionTestCase, make_contact_data, make_verification


class MojeidProcessorTest(TransactionTestCase):
    method = 'ANALYSIS'
    contact_id = ContactId('KRYTEN')
    contact_history_id = ContactHistoryId('42')

    async def test_check_complete_nothing(self):
        # Test no verified data.
        processor = MojeidProcessor(method=self.method)
        verification = await make_verification(self.session, contact_id=self.contact_id)

        self.assertFalse(await processor.check_complete(verification))

    async def test_check_complete_unknown(self):
        # Test verified data for a contact with missing verified organization (we don't know it's a person).
        processor = MojeidProcessor(method=self.method)
        verification = await make_verification(self.session, contact_id=self.contact_id)
        await make_contact_data(self.session, verification_id=verification.id,
                                contact_history_id=self.contact_history_id)

        self.assertFalse(await processor.check_complete(verification))

    async def test_check_complete_company_no_reg_num(self):
        # Test verified data for a company without company reg. number.
        processor = MojeidProcessor(method=self.method)
        verification = await make_verification(self.session, contact_id=self.contact_id)
        await make_contact_data(
            self.session, verification_id=verification.id, contact_history_id=self.contact_history_id,
            organization='JMC', verified_organization=True, address_city='', verified_address=True)

        self.assertFalse(await processor.check_complete(verification))

    async def test_check_complete_company_reg_num(self):
        # Test verified data for a company with company reg. number.
        processor = MojeidProcessor(method=self.method)
        verification = await make_verification(self.session, contact_id=self.contact_id)
        await make_contact_data(
            self.session, verification_id=verification.id, contact_history_id=self.contact_history_id,
            organization='JMC', verified_organization=True,
            company_registration_number='', verified_company_registration_number=True,
            address_city='', verified_address=True)

        self.assertTrue(await processor.check_complete(verification))
